@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Abderrahman Taha                                *
+ *   Copyright (C) 2007 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -285,5 +285,6 @@ public:
  void SpecialMorph_1();
  void SpecialMorph_2(GLfloat * , GLuint *, GLuint *, int);
  void SpecialMorph_3(GLfloat *, GLuint *);
-
+ void RunPovScript();
+ void stopcalculations();
 };
