@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Abderrahman Taha                                *
+ *   Copyright (C) 2007 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,7 +17,6 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
-
 #include "edit.h"
 #include <qimage.h>
 #include <qpixmap.h>
@@ -30,7 +29,6 @@
 #include <qfiledialog.h>
 #include <qstatusbar.h>
 #include <qmessagebox.h>
-//#include <qprinter.h>
 #include <qapplication.h>
 #include <qaccel.h>
 #include <qtextstream.h>
@@ -40,44 +38,28 @@
 
 #include "filesave.xpm"
 #include "fileopen.xpm"
-//#include "fileprint.xpm"
 
 editeur::editeur()
-    : QMainWindow( 0, "editeur", WDestructiveClose )
+    : QMainWindow( 0, "editeur", WDestructiveClose | WStyle_StaysOnTop)
 {
     workfile = "test.pov";
-     
-//    printer = new QPrinter;
+
     QPixmap openIcon, saveIcon, runIcon;
 
     QToolBar * fileTools = new QToolBar( this, "file operations" );
     fileTools->setLabel( tr("File Operations") );
 
     openIcon = QPixmap( fileopen );
-    QToolButton * fileOpen
-	= new QToolButton( openIcon, tr("Open File"), QString::null,
-			   this, SLOT(choose()), fileTools, "open file" );
+    QToolButton * fileOpen = new QToolButton( openIcon, tr("Open File"), QString::null,
+                           this, SLOT(choose()), fileTools, "open file" );
 
     saveIcon = QPixmap( filesave );
-    QToolButton * fileSave
-	= new QToolButton( saveIcon, tr("Save File"), QString::null,
-			   this, SLOT(save()), fileTools, "save file" );
-/*
-    printIcon = QPixmap( fileprint );
-    QToolButton * filePrint
-	= new QToolButton( printIcon, tr("Print File"), QString::null,
-			   this, SLOT(print()), fileTools, "print file" );
-
-    runIcon = QPixmap( "run.xpm" );
-    QToolButton * fileRun
-	= new QToolButton( runIcon, tr("Run Pov"), QString::null,
-			   this, SLOT(runpovray()), fileTools, "print file" );
-*/
+    QToolButton * fileSave = new QToolButton( saveIcon, tr("Save File"), QString::null, this, SLOT(save()), fileTools, "save file" );
 
     (void)QWhatsThis::whatsThisButton( fileTools );
 
     QString fileOpenText = tr("<p><img source=\"fileopen\"> "
-	         "Click this button to open a <em>new file</em>. <br>"
+         "Click this button to open a <em>new file</em>. <br>"
                  "You can also select the <b>Open</b> command "
                  "from the <b>File</b> menu.</p>");
 
@@ -96,36 +78,25 @@ editeur::editeur()
                  "are editeuring.\n You can also select the Print "
                  "command from the File menu.");
 
-//    QWhatsThis::add( filePrint, filePrintText );
-
-    // QWhatsThis::add( fileRun, filePrintText );
-
     QPopupMenu * file = new QPopupMenu( this );
     menuBar()->insertItem( tr("&File"), file );
 
-
     file->insertItem( tr("&New"), this, SLOT(newDoc()), CTRL+Key_N );
 
     int id;
     id = file->insertItem( openIcon, tr("&Open..."),
-			   this, SLOT(choose()), CTRL+Key_O );
+   this, SLOT(choose()), CTRL+Key_O );
     file->setWhatsThis( id, fileOpenText );
 
     id = file->insertItem( saveIcon, tr("&Save"),
-			   this, SLOT(save()), CTRL+Key_S );
+   this, SLOT(save()), CTRL+Key_S );
     file->setWhatsThis( id, fileSaveText );
 
     id = file->insertItem( tr("Save &As..."), this, SLOT(saveAs()) );
     file->setWhatsThis( id, fileSaveText );
 
     file->insertSeparator();
-/*
-    id = file->insertItem( printIcon, tr("&Print..."),
-			   this, SLOT(print()), CTRL+Key_P );
-    file->setWhatsThis( id, filePrintText );
 
-    file->insertSeparator();
-*/
     file->insertItem( tr("&Close"), this, SLOT(close()), CTRL+Key_W );
 
     file->insertItem( tr("&Quit"), qApp, SLOT( closeAllWindows() ), CTRL+Key_Q );
@@ -140,7 +111,7 @@ editeur::editeur()
     help->insertSeparator();
     help->insertItem( tr("What's &This"), this, SLOT(whatsThis()), SHIFT+Key_F1 );
 
-    e = new QTextEdit( this, "editeuror" );
+    e = new QTextEdit( this, "Editor" );
     e->setFocus();
     setCentralWidget( e );
     statusBar()->message( tr("Ready"), 2000 );
@@ -151,7 +122,6 @@ editeur::editeur()
 
 editeur::~editeur()
 {
-//    delete printer;
     delete e;
 }
 
@@ -159,9 +129,9 @@ void editeur::settext(const QString & txt )
 {
     e->setText(txt );
 }
+
 void editeur::append(const QString & txt )
 {
-    //e->setPaper(QBrush(QColor(0,0,0)));
     e->append(txt );
 }
 
@@ -169,6 +139,7 @@ void editeur::changecolor(const QColor & c )
 {
     e->setColor(c);
 }
+
 void editeur::newDoc()
 {
     editeur *ed = new editeur;
@@ -178,12 +149,9 @@ void editeur::newDoc()
 
 void editeur::choose()
 {
-    QString fn = QFileDialog::getOpenFileName( QString::null, QString::null,
-					       this);
-    if ( !fn.isEmpty() )
-	load( fn );
-    else
-	statusBar()->message( tr("Loading aborted"), 2000 );
+    QString fn = QFileDialog::getOpenFileName( "../examples", QString::null, this);
+    if ( !fn.isEmpty() ) load( fn );
+    else statusBar()->message( tr("Loading aborted"), 2000 );
     workfile = fn;
 }
 
@@ -192,13 +160,14 @@ void editeur::load( const QString &fileName )
 {
     QFile f( fileName );
     if ( !f.open( IO_ReadOnly ) )
-	return;
+     return;
 
     QTextStream ts( &f );
     e->setText( ts.read() );
     e->setModified( FALSE );
     setCaption( fileName );
     statusBar()->message( tr("Loaded document %1").arg(fileName), 2000 );
+
 }
 
 
@@ -206,9 +175,9 @@ void editeur::saveScript(QString &text, QString name)
 {
       QFile f( name );
     if ( !f.open( IO_WriteOnly ) ) {
-	statusBar()->message( tr("Could not write to %1").arg(name),
-			      2000 );
-	return;
+statusBar()->message( tr("Could not write to %1").arg(name),
+      2000 );
+return;
     }
 
     QTextStream t( &f );
@@ -221,16 +190,16 @@ void editeur::saveScript(QString &text, QString name)
 void editeur::save()
 {
     if ( filename.isEmpty() ) {
-	saveAs();
-	return;
+saveAs();
+return;
     }
 
     QString text = e->text();
     QFile f( filename );
     if ( !f.open( IO_WriteOnly ) ) {
-	statusBar()->message( tr("Could not write to %1").arg(filename),
-			      2000 );
-	return;
+statusBar()->message( tr("Could not write to %1").arg(filename),
+      2000 );
+return;
     }
 
     QTextStream t( &f );
@@ -248,14 +217,13 @@ void editeur::save()
 void editeur::saveAs()
 {
     QString fn = QFileDialog::getSaveFileName( QString::null, QString::null,
-					       this );
+       this );
     if ( !fn.isEmpty() ) {
-	filename = fn;
-	save();
+filename = fn;
+save();
     } else {
-	statusBar()->message( tr("Saving aborted"), 2000 );
+statusBar()->message( tr("Saving aborted"), 2000 );
     }
-
     workfile = fn;
 
 }
@@ -267,62 +235,62 @@ void editeur::print()
     const int Margin = 10;
     int pageNo = 1;
 
-    if ( printer->setup(this) ) {		// printer dialog
-	statusBar()->message( tr("Printing...") );
-	QPainter p;
-	if( !p.begin( printer ) )               // paint on printer
-	    return;
+    if ( printer->setup(this) ) {// printer dialog
+statusBar()->message( tr("Printing...") );
+QPainter p;
+if( !p.begin( printer ) )               // paint on printer
+    return;
 
-	p.setFont( e->font() );
-	int yPos	= 0;			// y-position for each line
-	QFontMetrics fm = p.fontMetrics();
-	QPaintDeviceMetrics metrics( printer ); // need width/height
-						// of printer surface
-	for( int i = 0 ; i < e->lines() ; i++ ) {
-	    if ( Margin + yPos > metrics.height() - Margin ) {
-		QString msg( "Printing (page " );
-		msg += QString::number( ++pageNo );
-		msg += ")...";
-		statusBar()->message( msg );
-		printer->newPage();		// no more room on this page
-		yPos = 0;			// back to top of page
-	    }
-	    p.drawText( Margin, Margin + yPos,
-			metrics.width(), fm.lineSpacing(),
-			ExpandTabs | DontClip,
-			e->text( i ) );
-	    yPos = yPos + fm.lineSpacing();
-	}
-	p.end();				// send job to printer
-	statusBar()->message( tr("Printing completed"), 2000 );
+p.setFont( e->font() );
+int yPos= 0;// y-position for each line
+QFontMetrics fm = p.fontMetrics();
+QPaintDeviceMetrics metrics( printer ); // need width/height
+// of printer surface
+for( int i = 0 ; i < e->lines() ; i++ ) {
+    if ( Margin + yPos > metrics.height() - Margin ) {
+QString msg( "Printing (page " );
+msg += QString::number( ++pageNo );
+msg += ")...";
+statusBar()->message( msg );
+printer->newPage();// no more room on this page
+yPos = 0;// back to top of page
+    }
+    p.drawText( Margin, Margin + yPos,
+metrics.width(), fm.lineSpacing(),
+ExpandTabs | DontClip,
+e->text( i ) );
+    yPos = yPos + fm.lineSpacing();
+}
+p.end();// send job to printer
+statusBar()->message( tr("Printing completed"), 2000 );
     } else {
-	statusBar()->message( tr("Printing aborted"), 2000 );
+statusBar()->message( tr("Printing aborted"), 2000 );
     }
 }
 */
 void editeur::closeEvent( QCloseEvent* ce )
 {
     if ( !e->isModified() ) {
-	ce->accept();
-	return;
+ce->accept();
+return;
     }
 
     switch( QMessageBox::information( this, tr("Qt Application Example"),
-				      tr("Do you want to save the changes"
-				      " to the document?"),
-				      tr("Yes"), tr("No"), tr("Cancel"),
-				      0, 1 ) ) {
+      tr("Do you want to save the changes"
+      " to the document?"),
+      tr("Yes"), tr("No"), tr("Cancel"),
+      0, 1 ) ) {
     case 0:
-	save();
-	ce->accept();
-	break;
+save();
+ce->accept();
+break;
     case 1:
-	ce->accept();
-	break;
+ce->accept();
+break;
     case 2:
     default: // just for sanity
-	ce->ignore();
-	break;
+ce->ignore();
+break;
     }
 }
 
@@ -330,29 +298,15 @@ void editeur::closeEvent( QCloseEvent* ce )
 void editeur::about()
 {
     QMessageBox::about( this, tr("Qt Application Example"),
-			tr("This example demonstrates simple use of "
-			"QMainWindow,\nQMenuBar and QToolBar."));
+tr("This example demonstrates simple use of "
+"QMainWindow,\nQMenuBar and QToolBar."));
 
 }
 
 void editeur::runpovray()
-{
-
-   //system("xterm&");
-/*
-if(workfile == "commencement" || workfile == "OBJECT.POV") {
-   QMessageBox message ;
-    
-    message.setText(tr("Please save this file once..."));
-    message.adjustSize () ;
-    message.exec();
-
-}
-else 
+{ /*int retour;
+retour = system("povray +I"+workfile+" +Oscene.tga +L/root/Desktop/pov/povray-3.6.1/scenes/incdemo/glasses  +FT +W250 +H250 +P +X10 &");
 */
-system("povray +I"+workfile+" +Oscene.tga +L/root/Desktop/pov/povray-3.6.1/scenes/incdemo/glasses  +FT +W250 +H250 +P +X10 &");
-
-
 }
 
 
