@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Abderrahman Taha                                *
+ *   Copyright (C) 2007 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,34 +17,50 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor,Boston, MA 02110-1301 USA             *
  ***************************************************************************/
-#include <qsplashscreen.h>
 #include <qapplication.h>
 #include <qmainwindow.h>
-#include "k3dsurf.h"
+#include <qfiledialog.h>
+#include <qcombobox.h>
+#include <qaction.h>
+#include <qfile.h>
+#include <qlineedit.h>
+#include <qmessagebox.h>
+#include <qtextedit.h>
+#include "menubar.h"
+#include "glviewer.h"
 
 
+
+//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
 int main( int argc, char **argv )
 {
     QApplication a( argc, argv );
-    k3dsurface  connect;
+    k3dsurface  mainwindow;
 #ifndef QT_NO_WIDGET_TOPEXTRA   // for Qt/Embedded minimal build
-    //connect.setCaption( "K3DSurf v0.5.3: Math for fun");
-    //connect.setWindowOpacity ( 0);
+
 #endif
-connect.setGeometry(6, 30, 1016, 672);
-a.setMainWidget( &connect );
-
-// Init Iso page:
-connect.Initisopage();
-//connect.ProcessNewIsoSurface();
+mainwindow.setGeometry(6, 30, 990, 724);
+a.setMainWidget( &mainwindow );
 
+menubar *  newmenu = new menubar(&mainwindow, &a);
+newmenu->constructmenubar();
 // Init Parametric Page:
-connect.ParametricSurfaceProcess(); /// To show the first model
-
-// Now show the result of all this stuff:
-connect.show();
-
-
+mainwindow.ParametricSurfaceProcess();
+// Init Iso page:
+mainwindow.Initisopage();
 
+/*
+mainwindow.setCaption("K3DSurf v0.6.1.5-Dev: Math for Fun");
+mainwindow.mesh->toggle();
+mainwindow.mesh->setText("Fill");
+mainwindow.box->setEnabled(TRUE);
+mainwindow.box->setText("Lines");
+mainwindow.IsoImplicitBox->insertItem("Chain");
+mainwindow.IsoImplicitBox->insertItem("Chain_2");
+mainwindow.textLabel1_14_4->setText("Examples (44)");
+*/
+//mainwindow.implicitfunct->setTextFormat(Qt::RichText);
+mainwindow.show();
+newmenu->loadConfig();
 return (a.exec());
 }
