@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Abderrahman Taha                                *
+ *   Copyright (C) 2007 by Abderrahman Taha                                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,19 +24,41 @@
 #include <qmainwindow.h>
 #include <qmovie.h>
 #include <qlabel.h>
+#include <qimage.h>
+#include <qlineedit.h>
+#include <qfiledialog.h>
+#include <qpicture.h>
+#include <qbutton.h>
+#include <qcheckbox.h>
+#include <qpushbutton.h>
+#include <qgroupbox.h>
+#include <qscrollbar.h>
 
 class videoplayer: public QMainWindow
 {
     Q_OBJECT
 
 public:
-    videoplayer();
-    ~videoplayer(); 
-private:
+    videoplayer(QImage);
+    ~videoplayer();
+public slots:
+    void connectcontrols();
+    void saveas();
+    void f_1(int);
+    void f_2();
+    void f_3();
+    void f_4();
+    void f_5();
+public:
     QMovie *m;
     QLabel *l;
-
-
+    QGroupBox * groupBox ;
+    QScrollBar * scrollBar55;
+    QCheckBox * pngcheckBox;
+    QCheckBox * jpgcheckBox;
+    QCheckBox * bmpcheckBox;
+    QPushButton * pushScreenshot;
+    QImage buf;
+    int image_quality;
 };
-
 //#endif
